Class: Fog::Compute::AWS::Flavors

Inherits:
Fog::Collection show all
Defined in:
lib/fog/aws/models/compute/flavors.rb

Instance Attribute Summary

Attributes inherited from Fog::Collection

#service

Instance Method Summary collapse

Methods inherited from Fog::Collection

#clear, #create, #destroy, #initialize, #inspect, #load, model, #model, #new, #reload, #table, #to_json

Methods included from Attributes::ClassMethods

#_load, #aliases, #attribute, #attributes, #identity, #ignore_attributes, #ignored_attributes

Methods included from Fog::Core::DeprecatedConnectionAccessors

#connection, #connection=, #prepare_service_value

Methods included from Attributes::InstanceMethods

#_dump, #attributes, #dup, #identity, #identity=, #merge_attributes, #new_record?, #persisted?, #requires, #requires_one

Constructor Details

This class inherits a constructor from Fog::Collection

Instance Method Details

#allObject

Returns an array of all flavors that have been created

AWS.flavors.all

Returns

Returns an array of all available instances and their general information

AWS.flavors.all <Fog::AWS::Compute::Flavors [

 <Fog::AWS::Compute::Flavor
   id="t1.micro",
   bits=0,
   cores=2,
   disk=0,
   name="Micro Instance",
   ram=613,
   ebs_optimized_available=false,
   instance_store_volumes=0
 >,
 <Fog::AWS::Compute::Flavor
   id="m1.small",
   bits=32,
   cores=1,
   disk=160,
   name="Small Instance",
   ram=1740.8,
   ebs_optimized_available=false,
   instance_store_volumes=1
 >,
 <Fog::AWS::Compute::Flavor
   id="m1.medium",
   bits=32,
   cores=2,
   disk=400,
   name="Medium Instance",
   ram=3750,
   ebs_optimized_available=false,
   instance_store_volumes=1
 >,
 <Fog::AWS::Compute::Flavor
   id="m1.large",
   bits=64,
   cores=4,
   disk=850,
   name="Large Instance",
   ram=7680,
   ebs_optimized_available=true
   instance_store_volumes=2
 >,
 <Fog::AWS::Compute::Flavor
   id="m1.xlarge",
   bits=64,
   cores=8,
   disk=1690,
   name="Extra Large Instance",
   ram=15360,
   ebs_optimized_available=true,
   instance_store_volumes=4

 >,
 <Fog::AWS::Compute::Flavor
   id="c1.medium",
   bits=32,
   cores=5,
   disk=350,
   name="High-CPU Medium",
   ram=1740.8,
   ebs_optimized_available=false,
   instance_store_volumes=1
 >,
 <Fog::AWS::Compute::Flavor
   id="c1.xlarge",
   bits=64,
   cores=20,
   disk=1690,
   name="High-CPU Extra Large",
   ram=7168,
   ebs_optimized_available=true,
   instance_store_volumes=4
 >,
 <Fog::AWS::Compute::Flavor
   id="m2.xlarge",
   bits=64,
   cores=6.5,
   disk=420,
   name="High-Memory Extra Large",
   ram=17510.4,
   ebs_optimized_available=false,
   instance_store_volumes=1
 >,
 <Fog::AWS::Compute::Flavor
   id="m2.2xlarge",
   bits=64,
   cores=13,
   disk=850,
   name="High Memory Double Extra Large",
   ram=35020.8,
   ebs_optimized_available=true,
   instance_store_volumes=1
 >,
 <Fog::AWS::Compute::Flavor
   id="m2.4xlarge",
   bits=64,
   cores=26,
   disk=1690,
   name="High Memory Quadruple Extra Large",
   ram=70041.6,
   ebs_optimized_available=true,
   instance_store_volumes=2
 >,
 <Fog::AWS::Compute::Flavor
   id="cc1.4xlarge",
   bits=64,
   cores=33.5,
   disk=1690,
   name="Cluster Compute Quadruple Extra Large",
   ram=23552,
   ebs_optimized_available=false,
   instance_store_volumes=0
 >,
 <Fog::Compute::AWS::Flavor
   id="m3.xlarge",
   bits=64,
   cores=13,
   disk=0,
   name="M3 Extra Large",
   ram=15360,
   ebs_optimized_available=true,
   instance_store_volumes=2
 >,
 <Fog::Compute::AWS::Flavor
   id="m3.2xlarge",
   bits=64,
   cores=26,
   disk=0,
   name="M3 Double Extra Large",
   ram=30720,
   ebs_optimized_available=true,
   instance_store_volumes=2
 >,
 <Fog::AWS::Compute::Flavor
   id="cc2.8xlarge",
   bits=64,
   cores=88,
   disk=3370,
   name="Cluster Compute Eight Extra Large",
   ram=61952,
   ebs_optimized_available=false,
   instance_store_volumes=4
 >,
 <Fog::AWS::Compute::Flavor
   id="cg1.4xlarge",
   bits=64,
   cores=33.5,
   disk=1690,
   name="Cluster GPU Quadruple Extra Large",
   ram=22528,
   ebs_optimized_available=false,
   instance_store_volumes=2
 >
]


481
482
483
484
# File 'lib/fog/aws/models/compute/flavors.rb', line 481

def all
  load(Fog::Compute::AWS::FLAVORS)
  self
end

#get(flavor_id) ⇒ Object

Used to retrieve a flavor flavor_id is required to get the associated flavor information. flavors available currently:

t1.micro m1.small, m1.medium, m1.large, m1.xlarge c1.medium, c1.xlarge c3.large, c3.xlarge, c3.2xlarge, c3.4xlarge, c3.8xlarge g2.2xlarge hs1.8xlarge m2.xlarge, m2.2xlarge, m2.4xlarge m3.xlarge, m3.2xlarge cr1.8xlarge cc1.4xlarge cc2.8xlarge cg1.4xlarge i2.xlarge, i2.2xlarge, i2.4xlarge, i2.8xlarge

You can run the following command to get the details: AWS.flavors.get("t1.micro")

Returns

AWS.flavors.get("t1.micro") <Fog::AWS::Compute::Flavor id="t1.micro", bits=0, cores=2, disk=0, name="Micro Instance", ram=613 ebs_optimized_available=false instance_store_volumes=0



522
523
524
# File 'lib/fog/aws/models/compute/flavors.rb', line 522

def get(flavor_id)
  self.class.new(:service => service).all.detect {|flavor| flavor.id == flavor_id}
end