Class: Fog::Compute::AWS::SecurityGroups
- Inherits:
-
Fog::Collection
- Object
- Array
- Fog::Collection
- Fog::Compute::AWS::SecurityGroups
- Defined in:
- lib/fog/aws/models/compute/security_groups.rb
Instance Attribute Summary
Attributes inherited from Fog::Collection
Instance Method Summary collapse
-
#all(filters = filters) ⇒ Object
Returns an array of all security groups that have been created.
-
#get(group_name) ⇒ Object
Used to retrieve a security group group name is required to get the associated flavor information.
-
#get_by_id(group_id) ⇒ Object
Used to retrieve a security group group id is required to get the associated flavor information.
-
#initialize(attributes) ⇒ SecurityGroups
constructor
Creates a new security group.
Methods inherited from Fog::Collection
#clear, #create, #destroy, #inspect, #load, model, #model, #new, #reload, #table, #to_json
Methods included from Attributes::ClassMethods
#_load, #aliases, #attribute, #attributes, #identity, #ignore_attributes, #ignored_attributes
Methods included from Fog::Core::DeprecatedConnectionAccessors
#connection, #connection=, #prepare_service_value
Methods included from Attributes::InstanceMethods
#_dump, #attributes, #dup, #identity, #identity=, #merge_attributes, #new_record?, #persisted?, #requires, #requires_one
Constructor Details
#initialize(attributes) ⇒ SecurityGroups
Creates a new security group
AWS.security_groups.new
Returns
Returns the details of the new image
AWS.security_groups.new <Fog::AWS::Compute::SecurityGroup name=nil,
description=nil, ip_permissions=nil, owner_id=nil vpc_id=nil
32 33 34 35 |
# File 'lib/fog/aws/models/compute/security_groups.rb', line 32 def initialize(attributes) self.filters ||= {} super end |
Instance Method Details
#all(filters = filters) ⇒ Object
Returns an array of all security groups that have been created
AWS.security_groups.all
Returns
Returns an array of all security groups
AWS.security_groups.all <Fog::AWS::Compute::SecurityGroups filters={}
[ <Fog::AWS::Compute::SecurityGroup name="default", description="default group", ip_permissions=["userId"=>"312571045469"], "fromPort"=>-1, "toPort"=>-1, "ipRanges"=>[], "ipProtocol"=>"icmp"}, "userId"=>"312571045469"], "fromPort"=>0, "toPort"=>65535, "ipRanges"=>[], "ipProtocol"=>"tcp"}, "userId"=>"312571045469"], "fromPort"=>0, "toPort"=>65535, "ipRanges"=>[], "ipProtocol"=>"udp"}], owner_id="312571045469" vpc_id=nill > ]
60 61 62 63 64 65 66 67 68 |
# File 'lib/fog/aws/models/compute/security_groups.rb', line 60 def all(filters = filters) unless filters.is_a?(Hash) Fog::Logger.deprecation("all with #{filters.class} param is deprecated, use all('group-name' => []) instead [light_black](#{caller.first})[/]") filters = {'group-name' => [*filters]} end self.filters = filters data = service.describe_security_groups(filters).body load(data['securityGroupInfo']) end |
#get(group_name) ⇒ Object
Used to retrieve a security group group name is required to get the associated flavor information.
You can run the following command to get the details: AWS.security_groups.get("default")
Returns
AWS.security_groups.get("default") <Fog::AWS::Compute::SecurityGroup name="default",
description="default group", ip_permissions=["userId"=>"312571045469"], "fromPort"=>-1, "toPort"=>-1, "ipRanges"=>[], "ipProtocol"=>"icmp"}, "userId"=>"312571045469"], "fromPort"=>0, "toPort"=>65535, "ipRanges"=>[], "ipProtocol"=>"tcp"}, "userId"=>"312571045469"], "fromPort"=>0, "toPort"=>65535, "ipRanges"=>[], "ipProtocol"=>"udp"}], owner_id="312571045469" vpc_id=nil
88 89 90 91 92 |
# File 'lib/fog/aws/models/compute/security_groups.rb', line 88 def get(group_name) if group_name self.class.new(:service => service).all('group-name' => group_name).first end end |
#get_by_id(group_id) ⇒ Object
Used to retrieve a security group group id is required to get the associated flavor information.
You can run the following command to get the details: AWS.security_groups.get_by_id("default")
Returns
AWS.security_groups.get_by_id("sg-123456") <Fog::AWS::Compute::SecurityGroup name="default",
description="default group", ip_permissions=["userId"=>"312571045469"], "fromPort"=>-1, "toPort"=>-1, "ipRanges"=>[], "ipProtocol"=>"icmp"}, "userId"=>"312571045469"], "fromPort"=>0, "toPort"=>65535, "ipRanges"=>[], "ipProtocol"=>"tcp"}, "userId"=>"312571045469"], "fromPort"=>0, "toPort"=>65535, "ipRanges"=>[], "ipProtocol"=>"udp"}], owner_id="312571045469"
111 112 113 114 115 |
# File 'lib/fog/aws/models/compute/security_groups.rb', line 111 def get_by_id(group_id) if group_id self.class.new(:service => service).all('group-id' => group_id).first end end |